@@ -67,7 +67,7 @@ def doModifyNamespace(args, parsed_globals):
     FormatOutput.output("action", json_obj, g_param[OptionsDefine.Output], g_param[OptionsDefine.Filter])
 
 
-def doModifyApplicationReplicas(args, parsed_globals):
+def doDescribeApplicationsStatus(args, parsed_globals):
     g_param = parse_global_arg(parsed_globals)
 
     if g_param[OptionsDefine.UseCVMRole.replace('-', '_')]:
@@ -92,11 +92,11 @@ def doModifyApplicationReplicas(args, parsed_globals):
     client = mod.TemClient(cred, g_param[OptionsDefine.Region], profile)
     client._sdkVersion += ("_CLI_" + __version__)
     models = MODELS_MAP[g_param[OptionsDefine.Version]]
-    model = models.ModifyApplicationReplicasRequest()
+    model = models.DescribeApplicationsStatusRequest()
     model.from_json_string(json.dumps(args))
     start_time = time.time()
     while True:
-        rsp = client.ModifyApplicationReplicas(model)
+        rsp = client.DescribeApplicationsStatus(model)
         result = rsp.to_json_string()
         try:
             json_obj = json.loads(result)
@@ -211,7 +211,7 @@ def doModifyIngress(args, parsed_globals):
     FormatOutput.output("action", json_obj, g_param[OptionsDefine.Output], g_param[OptionsDefine.Filter])
 
 
-def doDeployServiceV2(args, parsed_globals):
+def doModifyApplicationReplicas(args, parsed_globals):
     g_param = parse_global_arg(parsed_globals)
 
     if g_param[OptionsDefine.UseCVMRole.replace('-', '_')]:
@@ -236,11 +236,11 @@ def doDeployServiceV2(args, parsed_globals):
     client = mod.TemClient(cred, g_param[OptionsDefine.Region], profile)
     client._sdkVersion += ("_CLI_" + __version__)
     models = MODELS_MAP[g_param[OptionsDefine.Version]]
-    model = models.DeployServiceV2Request()
+    model = models.ModifyApplicationReplicasRequest()
     model.from_json_string(json.dumps(args))
     start_time = time.time()
     while True:
-        rsp = client.DeployServiceV2(model)
+        rsp = client.ModifyApplicationReplicas(model)
         result = rsp.to_json_string()
         try:
             json_obj = json.loads(result)
@@ -1075,6 +1075,54 @@ def doRestartServiceRunPod(args, parsed_globals):
     FormatOutput.output("action", json_obj, g_param[OptionsDefine.Output], g_param[OptionsDefine.Filter])
 
 
+def doDeployServiceV2(args, parsed_globals):
+    g_param = parse_global_arg(parsed_globals)
+
+    if g_param[OptionsDefine.UseCVMRole.replace('-', '_')]:
+        cred = credential.CVMRoleCredential()
+    elif g_param[OptionsDefine.RoleArn.replace('-', '_')] and g_param[OptionsDefine.RoleSessionName.replace('-', '_')]:
+        cred = credential.STSAssumeRoleCredential(
+            g_param[OptionsDefine.SecretId], g_param[OptionsDefine.SecretKey], g_param[OptionsDefine.RoleArn.replace('-', '_')],
+            g_param[OptionsDefine.RoleSessionName.replace('-', '_')]
+        )
+    else:
+        cred = credential.Credential(
+            g_param[OptionsDefine.SecretId], g_param[OptionsDefine.SecretKey], g_param[OptionsDefine.Token]
+        )
+    http_profile = HttpProfile(
+        reqTimeout=60 if g_param[OptionsDefine.Timeout] is None else int(g_param[OptionsDefine.Timeout]),
+        reqMethod="POST",
+        endpoint=g_param[OptionsDefine.Endpoint],
+        proxy=g_param[OptionsDefine.HttpsProxy.replace('-', '_')]
+    )
+    profile = ClientProfile(httpProfile=http_profile, signMethod="HmacSHA256")
+    mod = CLIENT_MAP[g_param[OptionsDefine.Version]]
+    client = mod.TemClient(cred, g_param[OptionsDefine.Region], profile)
+    client._sdkVersion += ("_CLI_" + __version__)
+    models = MODELS_MAP[g_param[OptionsDefine.Version]]
+    model = models.DeployServiceV2Request()
+    model.from_json_string(json.dumps(args))
+    start_time = time.time()
+    while True:
+        rsp = client.DeployServiceV2(model)
+        result = rsp.to_json_string()
+        try:
+            json_obj = json.loads(result)
+        except TypeError as e:
+            json_obj = json.loads(result.decode('utf-8'))  # python3.3
+        if not g_param[OptionsDefine.Waiter] or search(g_param['OptionsDefine.WaiterInfo']['expr'], json_obj) == g_param['OptionsDefine.WaiterInfo']['to']:
+            break
+        cur_time = time.time()
+        if cur_time - start_time >= g_param['OptionsDefine.WaiterInfo']['timeout']:
+            raise ClientError('Request timeout, wait `%s` to `%s` timeout, last request is %s' %
+            (g_param['OptionsDefine.WaiterInfo']['expr'], g_param['OptionsDefine.WaiterInfo']['to'],
+            search(g_param['OptionsDefine.WaiterInfo']['expr'], json_obj)))
+        else:
+            print('Inquiry result is %s.' % search(g_param['OptionsDefine.WaiterInfo']['expr'], json_obj))
+        time.sleep(g_param['OptionsDefine.WaiterInfo']['interval'])
+    FormatOutput.output("action", json_obj, g_param[OptionsDefine.Output], g_param[OptionsDefine.Filter])
+
+
 def doGenerateApplicationPackageDownloadUrl(args, parsed_globals):
     g_param = parse_global_arg(parsed_globals)
 
@@ -1665,10 +1713,10 @@ MODELS_MAP = {
 
 ACTION_MAP = {
     "ModifyNamespace": doModifyNamespace,
-    "ModifyApplicationReplicas": doModifyApplicationReplicas,
+    "DescribeApplicationsStatus": doDescribeApplicationsStatus,
     "GenerateDownloadUrl": doGenerateDownloadUrl,
     "ModifyIngress": doModifyIngress,
-    "DeployServiceV2": doDeployServiceV2,
+    "ModifyApplicationReplicas": doModifyApplicationReplicas,
     "CreateNamespace": doCreateNamespace,
     "DescribeServiceRunPodListV2": doDescribeServiceRunPodListV2,
     "DeleteApplication": doDeleteApplication,
@@ -1686,6 +1734,7 @@ ACTION_MAP = {
     "CreateCosToken": doCreateCosToken,
     "DescribeIngress": doDescribeIngress,
     "RestartServiceRunPod": doRestartServiceRunPod,
+    "DeployServiceV2": doDeployServiceV2,
     "GenerateApplicationPackageDownloadUrl": doGenerateApplicationPackageDownloadUrl,
     "CreateEnvironment": doCreateEnvironment,
     "DescribeIngresses": doDescribeIngresses,
